@@ -25,6 +25,14 @@
 #include <kpluginloader.h>
 #include <kpluginmetadata.h>
 
+class LibraryPathRestorer {
+public:
+    explicit LibraryPathRestorer(const QStringList &paths) : mPaths(paths) {}
+    ~LibraryPathRestorer() { QCoreApplication::setLibraryPaths(mPaths); }
+private:
+    QStringList mPaths;
+};
+
 class KPluginLoaderTest : public QObject
 {
     Q_OBJECT
@@ -32,118 +40,118 @@ class KPluginLoaderTest : public QObject
 private Q_SLOTS:
     void testFindPlugin_missing()
     {
-        const QString location = KPluginLoader::findPlugin("idonotexist");
+        const QString location = KPluginLoader::findPlugin(QStringLiteral("idonotexist"));
         QVERIFY2(location.isEmpty(), qPrintable(location));
     }
 
     void testFindPlugin()
     {
-        const QString location = KPluginLoader::findPlugin("jsonplugin");
+        const QString location = KPluginLoader::findPlugin(QStringLiteral("jsonplugin"));
         QVERIFY2(!location.isEmpty(), qPrintable(location));
     }
 
     void testPluginVersion()
     {
-        KPluginLoader vplugin("versionedplugin");
+        KPluginLoader vplugin(QStringLiteral("versionedplugin"));
         QCOMPARE(vplugin.pluginVersion(), quint32(5));
 
-        KPluginLoader vplugin2("versionedplugin");
+        KPluginLoader vplugin2(QStringLiteral("versionedplugin"));
         QCOMPARE(vplugin2.pluginVersion(), quint32(5));
 
-        KPluginLoader uplugin("unversionedplugin");
+        KPluginLoader uplugin(QStringLiteral("unversionedplugin"));
         QCOMPARE(uplugin.pluginVersion(), quint32(-1));
 
-        KPluginLoader jplugin(KPluginName("jsonplugin"));
+        KPluginLoader jplugin(KPluginName(QStringLiteral("jsonplugin")));
         QCOMPARE(jplugin.pluginVersion(), quint32(-1));
 
-        KPluginLoader eplugin(KPluginName::fromErrorString("there was an error"));
+        KPluginLoader eplugin(KPluginName::fromErrorString(QStringLiteral("there was an error")));
         QCOMPARE(eplugin.pluginVersion(), quint32(-1));
 
-        KPluginLoader noplugin("idonotexist");
+        KPluginLoader noplugin(QStringLiteral("idonotexist"));
         QCOMPARE(noplugin.pluginVersion(), quint32(-1));
     }
 
     void testPluginName()
     {
-        KPluginLoader vplugin("versionedplugin");
+        KPluginLoader vplugin(QStringLiteral("versionedplugin"));
         QCOMPARE(vplugin.pluginName(), QString::fromLatin1("versionedplugin"));
 
-        KPluginLoader jplugin(KPluginName("jsonplugin"));
+        KPluginLoader jplugin(KPluginName(QStringLiteral("jsonplugin")));
         QCOMPARE(jplugin.pluginName(), QString::fromLatin1("jsonplugin"));
 
-        KPluginLoader eplugin(KPluginName::fromErrorString("there was an error"));
+        KPluginLoader eplugin(KPluginName::fromErrorString(QStringLiteral("there was an error")));
         QVERIFY2(eplugin.pluginName().isEmpty(), qPrintable(eplugin.pluginName()));
 
-        KPluginLoader noplugin("idonotexist");
+        KPluginLoader noplugin(QStringLiteral("idonotexist"));
         QCOMPARE(noplugin.pluginName(), QString::fromLatin1("idonotexist"));
     }
 
     void testFactory()
     {
-        KPluginLoader vplugin("versionedplugin");
+        KPluginLoader vplugin(QStringLiteral("versionedplugin"));
         QVERIFY(vplugin.factory());
 
-        KPluginLoader jplugin(KPluginName("jsonplugin"));
+        KPluginLoader jplugin(KPluginName(QStringLiteral("jsonplugin")));
         QVERIFY(jplugin.factory());
 
-        KPluginLoader eplugin(KPluginName::fromErrorString("there was an error"));
+        KPluginLoader eplugin(KPluginName::fromErrorString(QStringLiteral("there was an error")));
         QVERIFY(!eplugin.factory());
 
-        KPluginLoader noplugin("idonotexist");
+        KPluginLoader noplugin(QStringLiteral("idonotexist"));
         QVERIFY(!noplugin.factory());
     }
 
     void testErrorString()
     {
-        KPluginLoader eplugin(KPluginName::fromErrorString("there was an error"));
+        KPluginLoader eplugin(KPluginName::fromErrorString(QStringLiteral("there was an error")));
         QCOMPARE(eplugin.errorString(), QString::fromLatin1("there was an error"));
     }
 
     void testFileName()
     {
-        KPluginLoader vplugin("versionedplugin");
+        KPluginLoader vplugin(QStringLiteral("versionedplugin"));
         QCOMPARE(QFileInfo(vplugin.fileName()).canonicalFilePath(),
                  QFileInfo(QStringLiteral(VERSIONEDPLUGIN_FILE)).canonicalFilePath());
 
-        KPluginLoader jplugin(KPluginName("jsonplugin"));
+        KPluginLoader jplugin(KPluginName(QStringLiteral("jsonplugin")));
         QCOMPARE(QFileInfo(jplugin.fileName()).canonicalFilePath(),
                  QFileInfo(QStringLiteral(JSONPLUGIN_FILE)).canonicalFilePath());
 
-        KPluginLoader eplugin(KPluginName::fromErrorString("there was an error"));
+        KPluginLoader eplugin(KPluginName::fromErrorString(QStringLiteral("there was an error")));
         QVERIFY2(eplugin.fileName().isEmpty(), qPrintable(eplugin.fileName()));
 
-        KPluginLoader noplugin("idonotexist");
+        KPluginLoader noplugin(QStringLiteral("idonotexist"));
         QVERIFY2(noplugin.fileName().isEmpty(), qPrintable(noplugin.fileName()));
     }
 
     void testInstance()
     {
-        KPluginLoader vplugin("versionedplugin");
+        KPluginLoader vplugin(QStringLiteral("versionedplugin"));
         QVERIFY(vplugin.instance());
 
-        KPluginLoader jplugin(KPluginName("jsonplugin"));
+        KPluginLoader jplugin(KPluginName(QStringLiteral("jsonplugin")));
         QVERIFY(jplugin.instance());
 
-        KPluginLoader eplugin(KPluginName::fromErrorString("there was an error"));
+        KPluginLoader eplugin(KPluginName::fromErrorString(QStringLiteral("there was an error")));
         QVERIFY(!eplugin.instance());
 
-        KPluginLoader noplugin("idonotexist");
+        KPluginLoader noplugin(QStringLiteral("idonotexist"));
         QVERIFY(!noplugin.instance());
     }
 
     void testIsLoaded()
     {
-        KPluginLoader vplugin("versionedplugin");
+        KPluginLoader vplugin(QStringLiteral("versionedplugin"));
         QVERIFY(!vplugin.isLoaded());
         QVERIFY(vplugin.load());
         QVERIFY(vplugin.isLoaded());
 
-        KPluginLoader jplugin(KPluginName("jsonplugin"));
+        KPluginLoader jplugin(KPluginName(QStringLiteral("jsonplugin")));
         QVERIFY(!jplugin.isLoaded());
         QVERIFY(jplugin.load());
         QVERIFY(jplugin.isLoaded());
 
-        KPluginLoader aplugin("alwaysunloadplugin");
+        KPluginLoader aplugin(QStringLiteral("alwaysunloadplugin"));
         QVERIFY(!aplugin.isLoaded());
         QVERIFY(aplugin.load());
         QVERIFY(aplugin.isLoaded());
@@ -153,12 +161,12 @@ private Q_SLOTS:
             qDebug() << "Could not unload alwaysunloadplugin:" << aplugin.errorString();
         }
 
-        KPluginLoader eplugin(KPluginName::fromErrorString("there was an error"));
+        KPluginLoader eplugin(KPluginName::fromErrorString(QStringLiteral("there was an error")));
         QVERIFY(!eplugin.isLoaded());
         QVERIFY(!eplugin.load());
         QVERIFY(!eplugin.isLoaded());
 
-        KPluginLoader noplugin("idonotexist");
+        KPluginLoader noplugin(QStringLiteral("idonotexist"));
         QVERIFY(!noplugin.isLoaded());
         QVERIFY(!noplugin.load());
         QVERIFY(!noplugin.isLoaded());
@@ -166,57 +174,57 @@ private Q_SLOTS:
 
     void testLoad()
     {
-        KPluginLoader vplugin("versionedplugin");
+        KPluginLoader vplugin(QStringLiteral("versionedplugin"));
         QVERIFY(vplugin.load());
 
-        KPluginLoader jplugin(KPluginName("jsonplugin"));
+        KPluginLoader jplugin(KPluginName(QStringLiteral("jsonplugin")));
         QVERIFY(jplugin.load());
 
-        KPluginLoader eplugin(KPluginName::fromErrorString("there was an error"));
+        KPluginLoader eplugin(KPluginName::fromErrorString(QStringLiteral("there was an error")));
         QVERIFY(!eplugin.load());
 
-        KPluginLoader noplugin("idonotexist");
+        KPluginLoader noplugin(QStringLiteral("idonotexist"));
         QVERIFY(!noplugin.load());
     }
 
     void testLoadHints()
     {
-        KPluginLoader aplugin("alwaysunloadplugin");
+        KPluginLoader aplugin(QStringLiteral("alwaysunloadplugin"));
         aplugin.setLoadHints(QLibrary::ResolveAllSymbolsHint);
         QCOMPARE(aplugin.loadHints(), QLibrary::ResolveAllSymbolsHint);
     }
 
     void testMetaData()
     {
-        KPluginLoader aplugin("alwaysunloadplugin");
+        KPluginLoader aplugin(QStringLiteral("alwaysunloadplugin"));
         QJsonObject ametadata = aplugin.metaData();
         QVERIFY(!ametadata.isEmpty());
-        QVERIFY(ametadata.keys().contains("IID"));
-        QJsonValue ametadata_metadata = ametadata.value("MetaData");
+        QVERIFY(ametadata.keys().contains(QStringLiteral("IID")));
+        QJsonValue ametadata_metadata = ametadata.value(QStringLiteral("MetaData"));
         QVERIFY(ametadata_metadata.toObject().isEmpty());
         QVERIFY(!aplugin.isLoaded()); // didn't load anything
 
-        KPluginLoader jplugin(KPluginName("jsonplugin"));
+        KPluginLoader jplugin(KPluginName(QStringLiteral("jsonplugin")));
         QJsonObject jmetadata = jplugin.metaData();
         QVERIFY(!jmetadata.isEmpty());
-        QJsonValue jmetadata_metadata = jmetadata.value("MetaData");
+        QJsonValue jmetadata_metadata = jmetadata.value(QStringLiteral("MetaData"));
         QVERIFY(jmetadata_metadata.isObject());
         QJsonObject jmetadata_obj = jmetadata_metadata.toObject();
         QVERIFY(!jmetadata_obj.isEmpty());
-        QJsonValue comment = jmetadata_obj.value("KPlugin").toObject().value("Description");
+        QJsonValue comment = jmetadata_obj.value(QStringLiteral("KPlugin")).toObject().value(QStringLiteral("Description"));
         QVERIFY(comment.isString());
         QCOMPARE(comment.toString(), QString::fromLatin1("This is a plugin"));
 
-        KPluginLoader eplugin(KPluginName::fromErrorString("there was an error"));
+        KPluginLoader eplugin(KPluginName::fromErrorString(QStringLiteral("there was an error")));
         QVERIFY(eplugin.metaData().isEmpty());
 
-        KPluginLoader noplugin("idonotexist");
+        KPluginLoader noplugin(QStringLiteral("idonotexist"));
         QVERIFY(noplugin.metaData().isEmpty());
     }
 
     void testUnload()
     {
-        KPluginLoader aplugin("alwaysunloadplugin");
+        KPluginLoader aplugin(QStringLiteral("alwaysunloadplugin"));
         QVERIFY(aplugin.load());
         // may need QEXPECT_FAIL on some platforms...
         QVERIFY(aplugin.unload());
@@ -224,28 +232,28 @@ private Q_SLOTS:
 
     void testInstantiatePlugins()
     {
-        const QString plugin1Path = KPluginLoader::findPlugin("jsonplugin");
+        const QString plugin1Path = KPluginLoader::findPlugin(QStringLiteral("jsonplugin"));
         QVERIFY2(!plugin1Path.isEmpty(), qPrintable(plugin1Path));
-        const QString plugin2Path = KPluginLoader::findPlugin("unversionedplugin");
+        const QString plugin2Path = KPluginLoader::findPlugin(QStringLiteral("unversionedplugin"));
         QVERIFY2(!plugin2Path.isEmpty(), qPrintable(plugin2Path));
-        const QString plugin3Path = KPluginLoader::findPlugin("jsonplugin2");
+        const QString plugin3Path = KPluginLoader::findPlugin(QStringLiteral("jsonplugin2"));
         QVERIFY2(!plugin3Path.isEmpty(), qPrintable(plugin3Path));
 
         QTemporaryDir temp;
         QVERIFY(temp.isValid());
         QDir dir(temp.path());
         QVERIFY2(QFile::copy(plugin1Path, dir.absoluteFilePath(QFileInfo(plugin1Path).fileName())),
-            qPrintable(dir.absoluteFilePath(QFileInfo(plugin1Path).fileName())));
+                 qPrintable(dir.absoluteFilePath(QFileInfo(plugin1Path).fileName())));
         QVERIFY2(QFile::copy(plugin2Path, dir.absoluteFilePath(QFileInfo(plugin2Path).fileName())),
-            qPrintable(dir.absoluteFilePath(QFileInfo(plugin2Path).fileName())));
+                 qPrintable(dir.absoluteFilePath(QFileInfo(plugin2Path).fileName())));
         QVERIFY2(QFile::copy(plugin3Path, dir.absoluteFilePath(QFileInfo(plugin3Path).fileName())),
-            qPrintable(dir.absoluteFilePath(QFileInfo(plugin3Path).fileName())));
+                 qPrintable(dir.absoluteFilePath(QFileInfo(plugin3Path).fileName())));
 
         // only jsonplugin, since unversionedplugin has no json metadata
         QList<QObject*> plugins = KPluginLoader::instantiatePlugins(temp.path());
         QCOMPARE(plugins.size(), 2);
-        QStringList classNames = QStringList() << plugins[0]->metaObject()->className()
-            << plugins[1]->metaObject()->className();
+        QStringList classNames = QStringList() << QString::fromLatin1(plugins[0]->metaObject()->className())
+                << QString::fromLatin1(plugins[1]->metaObject()->className());
         classNames.sort();
         QCOMPARE(classNames[0], QStringLiteral("jsonplugin2"));
         QCOMPARE(classNames[1], QStringLiteral("jsonpluginfa"));
@@ -253,19 +261,19 @@ private Q_SLOTS:
 
         //try filter
         plugins = KPluginLoader::instantiatePlugins(temp.path(), [](const KPluginMetaData & md) {
-            return md.pluginId() == "jsonplugin";
+            return md.pluginId() == QStringLiteral("jsonplugin");
         });
         QCOMPARE(plugins.size(), 1);
         QCOMPARE(plugins[0]->metaObject()->className(), "jsonpluginfa");
         qDeleteAll(plugins);
 
         plugins = KPluginLoader::instantiatePlugins(temp.path(), [](const KPluginMetaData & md) {
-            return md.pluginId() == "unversionedplugin";
+            return md.pluginId() == QStringLiteral("unversionedplugin");
         });
         QCOMPARE(plugins.size(), 0);
 
         plugins = KPluginLoader::instantiatePlugins(temp.path(), [](const KPluginMetaData & md) {
-            return md.pluginId() == "foobar"; // ID does not match file name, is set in JSON
+            return md.pluginId() == QStringLiteral("foobar"); // ID does not match file name, is set in JSON
         });
         QCOMPARE(plugins.size(), 1);
         QCOMPARE(plugins[0]->metaObject()->className(), "jsonplugin2");
@@ -280,14 +288,15 @@ private Q_SLOTS:
 
         const QString subDirName = dir.dirName();
         QVERIFY(dir.cdUp()); // should now point to /tmp on Linux
+        LibraryPathRestorer restorer(QCoreApplication::libraryPaths());
         // instantiate using relative path
         // make sure library path is set up correctly
         QCoreApplication::setLibraryPaths(QStringList() << dir.absolutePath());
         QVERIFY(!QDir::isAbsolutePath(subDirName));
         plugins = KPluginLoader::instantiatePlugins(subDirName);
         QCOMPARE(plugins.size(), 2);
-        classNames = QStringList() << plugins[0]->metaObject()->className()
-            << plugins[1]->metaObject()->className();
+        classNames = QStringList() << QString::fromLatin1(plugins[0]->metaObject()->className())
+                << QString::fromLatin1(plugins[1]->metaObject()->className());
         classNames.sort();
         QCOMPARE(classNames[0], QStringLiteral("jsonplugin2"));
         QCOMPARE(classNames[1], QStringLiteral("jsonpluginfa"));
@@ -296,24 +305,25 @@ private Q_SLOTS:
 
     void testFindPlugins()
     {
-        const QString plugin1Path = KPluginLoader::findPlugin("jsonplugin");
+        const QString plugin1Path = KPluginLoader::findPlugin(QStringLiteral("jsonplugin"));
         QVERIFY2(!plugin1Path.isEmpty(), qPrintable(plugin1Path));
-        const QString plugin2Path = KPluginLoader::findPlugin("unversionedplugin");
+        const QString plugin2Path = KPluginLoader::findPlugin(QStringLiteral("unversionedplugin"));
         QVERIFY2(!plugin2Path.isEmpty(), qPrintable(plugin2Path));
-        const QString plugin3Path = KPluginLoader::findPlugin("jsonplugin2");
+        const QString plugin3Path = KPluginLoader::findPlugin(QStringLiteral("jsonplugin2"));
         QVERIFY2(!plugin3Path.isEmpty(), qPrintable(plugin3Path));
 
         QTemporaryDir temp;
         QVERIFY(temp.isValid());
         QDir dir(temp.path());
-        QVERIFY(dir.mkdir("kpluginmetadatatest"));
-        QVERIFY(dir.cd("kpluginmetadatatest"));
+        QVERIFY(dir.mkdir(QStringLiteral("kpluginmetadatatest")));
+        QVERIFY(dir.cd(QStringLiteral("kpluginmetadatatest")));
         QVERIFY2(QFile::copy(plugin1Path, dir.absoluteFilePath(QFileInfo(plugin1Path).fileName())),
-            qPrintable(dir.absoluteFilePath(QFileInfo(plugin1Path).fileName())));
+                 qPrintable(dir.absoluteFilePath(QFileInfo(plugin1Path).fileName())));
         QVERIFY2(QFile::copy(plugin2Path, dir.absoluteFilePath(QFileInfo(plugin2Path).fileName())),
-            qPrintable(dir.absoluteFilePath(QFileInfo(plugin2Path).fileName())));
+                 qPrintable(dir.absoluteFilePath(QFileInfo(plugin2Path).fileName())));
         QVERIFY2(QFile::copy(plugin3Path, dir.absoluteFilePath(QFileInfo(plugin3Path).fileName())),
-            qPrintable(dir.absoluteFilePath(QFileInfo(plugin3Path).fileName())));
+                 qPrintable(dir.absoluteFilePath(QFileInfo(plugin3Path).fileName())));
+        LibraryPathRestorer restorer(QCoreApplication::libraryPaths());
         // we only want plugins from our temporary dir
         QCoreApplication::setLibraryPaths(QStringList() << temp.path());
 
@@ -321,7 +331,7 @@ private Q_SLOTS:
             return a.pluginId() < b.pluginId();
         };
         // it should find jsonplugin and jsonplugin2 since unversionedplugin does not have any meta data
-        auto plugins = KPluginLoader::findPlugins("kpluginmetadatatest");
+        auto plugins = KPluginLoader::findPlugins(QStringLiteral("kpluginmetadatatest"));
         std::sort(plugins.begin(), plugins.end(), sortPlugins);
         QCOMPARE(plugins.size(), 2);
         QCOMPARE(plugins[0].pluginId(), QStringLiteral("foobar")); // ID is not the filename, it is set in the JSON metadata
@@ -330,31 +340,31 @@ private Q_SLOTS:
         QCOMPARE(plugins[1].description(), QStringLiteral("This is a plugin"));
 
         // filter accepts none
-        plugins = KPluginLoader::findPlugins("kpluginmetadatatest", [](const KPluginMetaData &) { return false; });
+        plugins = KPluginLoader::findPlugins(QStringLiteral("kpluginmetadatatest"), [](const KPluginMetaData &) { return false; });
         std::sort(plugins.begin(), plugins.end(), sortPlugins);
         QCOMPARE(plugins.size(), 0);
 
         // filter accepts all
-        plugins = KPluginLoader::findPlugins("kpluginmetadatatest", [](const KPluginMetaData &) { return true; });
+        plugins = KPluginLoader::findPlugins(QStringLiteral("kpluginmetadatatest"), [](const KPluginMetaData &) { return true; });
         std::sort(plugins.begin(), plugins.end(), sortPlugins);
         QCOMPARE(plugins.size(), 2);
         QCOMPARE(plugins[0].description(), QStringLiteral("This is another plugin"));
         QCOMPARE(plugins[1].description(), QStringLiteral("This is a plugin"));
 
         // invalid std::function as filter
-        plugins = KPluginLoader::findPlugins("kpluginmetadatatest");
+        plugins = KPluginLoader::findPlugins(QStringLiteral("kpluginmetadatatest"));
         std::sort(plugins.begin(), plugins.end(), sortPlugins);
         QCOMPARE(plugins.size(), 2);
         QCOMPARE(plugins[0].description(), QStringLiteral("This is another plugin"));
         QCOMPARE(plugins[1].description(), QStringLiteral("This is a plugin"));
 
         // by plugin id
-        plugins = KPluginLoader::findPluginsById(dir.absolutePath(), "foobar");
+        plugins = KPluginLoader::findPluginsById(dir.absolutePath(), QStringLiteral("foobar"));
         QCOMPARE(plugins.size(), 1);
         QCOMPARE(plugins[0].description(), QStringLiteral("This is another plugin"));
 
         // by plugin invalid id
-        plugins = KPluginLoader::findPluginsById(dir.absolutePath(), "invalidid");
+        plugins = KPluginLoader::findPluginsById(dir.absolutePath(), QStringLiteral("invalidid"));
         QCOMPARE(plugins.size(), 0);
 
         // absolute path, no filter
@@ -367,18 +377,18 @@ private Q_SLOTS:
 
     void testForEachPlugin()
     {
-        const QString jsonPluginSrc = KPluginLoader::findPlugin("jsonplugin");
+        const QString jsonPluginSrc = KPluginLoader::findPlugin(QStringLiteral("jsonplugin"));
         QVERIFY2(!jsonPluginSrc.isEmpty(), qPrintable(jsonPluginSrc));
-        const QString unversionedPluginSrc = KPluginLoader::findPlugin("unversionedplugin");
+        const QString unversionedPluginSrc = KPluginLoader::findPlugin(QStringLiteral("unversionedplugin"));
         QVERIFY2(!unversionedPluginSrc.isEmpty(), qPrintable(unversionedPluginSrc));
-        const QString jsonPlugin2Src = KPluginLoader::findPlugin("jsonplugin2");
+        const QString jsonPlugin2Src = KPluginLoader::findPlugin(QStringLiteral("jsonplugin2"));
         QVERIFY2(!jsonPlugin2Src.isEmpty(), qPrintable(jsonPlugin2Src));
 
         QTemporaryDir temp;
         QVERIFY(temp.isValid());
         QDir dir(temp.path());
-        QVERIFY(dir.mkdir("for-each-plugin"));
-        QVERIFY(dir.cd("for-each-plugin"));
+        QVERIFY(dir.mkdir(QStringLiteral("for-each-plugin")));
+        QVERIFY(dir.cd(QStringLiteral("for-each-plugin")));
         const QString jsonPluginDest = dir.absoluteFilePath(QFileInfo(jsonPluginSrc).fileName());
         QVERIFY2(QFile::copy(jsonPluginSrc, jsonPluginDest), qPrintable(jsonPluginDest));
         const QString unversionedPluginDest = dir.absoluteFilePath(QFileInfo(unversionedPluginSrc).fileName());
@@ -387,8 +397,8 @@ private Q_SLOTS:
         QTemporaryDir temp2;
         QVERIFY(temp2.isValid());
         QDir dir2(temp2.path());
-        QVERIFY(dir2.mkdir("for-each-plugin"));
-        QVERIFY(dir2.cd("for-each-plugin"));
+        QVERIFY(dir2.mkdir(QStringLiteral("for-each-plugin")));
+        QVERIFY(dir2.cd(QStringLiteral("for-each-plugin")));
         const QString jsonPlugin2Dest = dir2.absoluteFilePath(QFileInfo(jsonPlugin2Src).fileName());
         QVERIFY2(QFile::copy(jsonPlugin2Src, jsonPlugin2Dest), qPrintable(jsonPlugin2Dest));
 
@@ -416,11 +426,12 @@ private Q_SLOTS:
 
         // now test relative paths
 
+        LibraryPathRestorer restorer(QCoreApplication::libraryPaths());
         QCoreApplication::setLibraryPaths(QStringList() << temp.path());
         expectedPlugins = QStringList() << jsonPluginDest << unversionedPluginDest;
         expectedPlugins.sort();
         foundPlugins.clear();
-        KPluginLoader::forEachPlugin("for-each-plugin", addToFoundPlugins);
+        KPluginLoader::forEachPlugin(QStringLiteral("for-each-plugin"), addToFoundPlugins);
         foundPlugins.sort();
         QCOMPARE(foundPlugins, expectedPlugins);
 
@@ -428,7 +439,7 @@ private Q_SLOTS:
         expectedPlugins = QStringList() << jsonPlugin2Dest;
         expectedPlugins.sort();
         foundPlugins.clear();
-        KPluginLoader::forEachPlugin("for-each-plugin", addToFoundPlugins);
+        KPluginLoader::forEachPlugin(QStringLiteral("for-each-plugin"), addToFoundPlugins);
         foundPlugins.sort();
         QCOMPARE(foundPlugins, expectedPlugins);
 
@@ -436,7 +447,7 @@ private Q_SLOTS:
         expectedPlugins = QStringList() << jsonPluginDest << unversionedPluginDest << jsonPlugin2Dest;
         expectedPlugins.sort();
         foundPlugins.clear();
-        KPluginLoader::forEachPlugin("for-each-plugin", addToFoundPlugins);
+        KPluginLoader::forEachPlugin(QStringLiteral("for-each-plugin"), addToFoundPlugins);
         foundPlugins.sort();
         QCOMPARE(foundPlugins, expectedPlugins);
     }
