@@ -410,20 +410,33 @@ KAboutLicense KAboutLicense::byKeyword(const QString &rawKeyword)
         { "gpl", KAboutLicense::GPL },
         { "gplv2", KAboutLicense::GPL_V2 },
         { "gplv2+", KAboutLicense::GPL_V2 },
+        { "gpl20", KAboutLicense::GPL_V2 },
+        { "gpl20+", KAboutLicense::GPL_V2 },
         { "lgpl", KAboutLicense::LGPL },
         { "lgplv2", KAboutLicense::LGPL_V2 },
         { "lgplv2+", KAboutLicense::LGPL_V2 },
+        { "lgpl20", KAboutLicense::LGPL_V2 },
+        { "lgpl20+", KAboutLicense::LGPL_V2 },
         { "bsd", KAboutLicense::BSDL },
+        { "bsd2clause", KAboutLicense::BSDL },
         { "artistic", KAboutLicense::Artistic },
+        { "artistic10", KAboutLicense::Artistic },
         { "qpl", KAboutLicense::QPL },
         { "qplv1", KAboutLicense::QPL_V1_0 },
         { "qplv10", KAboutLicense::QPL_V1_0 },
+        { "qpl10", KAboutLicense::QPL_V1_0 },
         { "gplv3", KAboutLicense::GPL_V3 },
         { "gplv3+", KAboutLicense::GPL_V3 },
+        { "gpl30", KAboutLicense::GPL_V3 },
+        { "gpl30+", KAboutLicense::GPL_V3 },
         { "lgplv3", KAboutLicense::LGPL_V3 },
         { "lgplv3+", KAboutLicense::LGPL_V3 },
+        { "lgpl30", KAboutLicense::LGPL_V3 },
+        { "lgpl30+", KAboutLicense::LGPL_V3 },
         { "lgplv21", KAboutLicense::LGPL_V2_1 },
-        { "lgplv21+", KAboutLicense::LGPL_V2_1 }
+        { "lgplv21+", KAboutLicense::LGPL_V2_1 },
+        { "lgpl21", KAboutLicense::LGPL_V2_1 },
+        { "lgpl21+", KAboutLicense::LGPL_V2_1 },
     };
 
     // Normalize keyword.
@@ -431,6 +444,7 @@ KAboutLicense KAboutLicense::byKeyword(const QString &rawKeyword)
     keyword = keyword.toLower();
     keyword.remove(QLatin1Char(' '));
     keyword.remove(QLatin1Char('.'));
+    keyword.remove(QLatin1Char('-'));
 
     LicenseKey license = licenseDict.value(keyword.toLatin1(),
                                            KAboutLicense::Custom);
@@ -920,7 +934,7 @@ QString KAboutData::aboutTranslationTeam()
                "<p>KDE is translated into many languages thanks to the work "
                "of the translation teams all over the world.</p>"
                "<p>For more information on KDE internationalization "
-               "visit <a href=\"http://l10n.kde.org\">http://l10n.kde.org</a></p>",
+               "visit <a href=\"https://l10n.kde.org\">https://l10n.kde.org</a></p>",
                "replace this with information about your translation team"
            );
 }
@@ -1163,12 +1177,12 @@ void KAboutData::processCommandLine(QCommandLineParser *parser)
                 if (!person.emailAddress().isEmpty()) {
                     authorData.append(QStringLiteral(" <") + person.emailAddress() + QStringLiteral(">"));
                 }
-                printf("%s\n", qPrintable(authorData));;
+                printf("%s\n", qPrintable(authorData));
             }
         }
         if (!customAuthorTextEnabled()) {
             if (bugAddress() == QLatin1String("submit@bugs.kde.org") ) {
-                printf("%s\n", qPrintable(QCoreApplication::translate("KAboutData CLI", "Please use http://bugs.kde.org to report bugs.")));
+                printf("%s\n", qPrintable(QCoreApplication::translate("KAboutData CLI", "Please use https://bugs.kde.org to report bugs.")));
             } else if (!bugAddress().isEmpty()) {
                 printf("%s\n", qPrintable(QCoreApplication::translate("KAboutData CLI", "Please report bugs to %1.").arg(bugAddress())));
             }
