@@ -4,6 +4,7 @@
  * Copyright (C) 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
  * Copyright (C) 2010 Teo Mrnjavac <teo@kde.org>
  * Copyright (C) 2013 David Faure <faure+bluesystems@kde.org>
+ * Copyright (C) 2017 Harald Sitter <sitter@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -205,6 +206,14 @@ public:
         FullName
     };
 
+    /**
+     * Whether later versions of the license are allowed.
+     */
+    enum VersionRestriction {
+        OnlyThisVersion,
+        OrLaterVersions
+    };
+
     /**
      * Copy constructor.  Performs a deep copy.
      * @param other object to copy
@@ -243,7 +252,24 @@ public:
     KAboutLicense::LicenseKey key() const;
 
     /**
-     * Fetch a known license by a keyword.
+     * Returns the SPDX license expression of this license.
+     * If the underlying license cannot be expressed as a SPDX expression a null string is returned.
+     *
+     * @note SPDX expression are expansive constructs. If you parse the return value, do it in a
+     *   SPDX specification compliant manner by splitting on whitespaces to discard unwanted
+     *   informationor or by using a complete SPDX license expression parser.
+     * @note SPDX identifiers are case-insensitive. Do not use case-senstivie checks on the return
+     *   value.
+     * @see https://spdx.org/licenses
+     * @return SPDX license expression or QString() if the license has no identifier. Compliant
+     *   with SPDX 2.1.
+     *
+     * @since 5.37
+     */
+    QString spdx() const;
+
+    /**
+     * Fetch a known license by a keyword/spdx ID
      *
      * Frequently the license data is provided by a terse keyword-like string,
      * e.g. by a field in a .desktop file. Using this method, an application
@@ -266,6 +292,12 @@ public:
     static KAboutLicense byKeyword(const QString &keyword);
 
 private:
+    /**
+     * @internal Used by KAboutData to construct a predefined license.
+     */
+    explicit KAboutLicense(enum KAboutLicense::LicenseKey licenseType,
+                           enum KAboutLicense::VersionRestriction versionRestriction,
+                           const KAboutData *aboutData);
     /**
      * @internal Used by KAboutData to construct a predefined license.
      */
@@ -288,6 +320,8 @@ private:
 };
 
 /**
+ * @class KAboutData kaboutdata.h KAboutData
+ *
  * This class is used to store information about a program or plugin.
  * It can store such values as version number, program name, home page, address
  * for bug reporting, multiple authors and contributors
@@ -328,8 +362,6 @@ private:
  * // needed for environments where the icon name is not extracted from
  * // the information in the application's desktop file
  * QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("foo")));
- * // with the application metadata set, register to the D-Bus session
- * KDBusService programDBusService(KDBusService::Multiple | KDBusService::NoExitOnFailure);
  *
  * // integrate with commandline argument handling
  * QCommandLineParser parser;
@@ -338,6 +370,9 @@ private:
  * [...]
  * parser.process(app);
  * aboutData.processCommandLine(&parser);
+ *
+ * // with the application metadata set, register to the D-Bus session
+ * KDBusService programDBusService(KDBusService::Multiple | KDBusService::NoExitOnFailure);
  * @endcode
  *
  * @short Holds information needed by the "About" box and other
@@ -441,7 +476,7 @@ public:
      * @param bugAddress The bug report address string, an email address or a URL.
      *        This defaults to the kde.org bug system.
      *
-     * @note The @arg homePageAddress argument is used to derive a default organization
+     * @note The @p homePageAddress argument is used to derive a default organization
      * domain for the application (which is used to register on the session D-Bus,
      * locate the appropriate desktop file, etc.), by taking the host name and dropping
      * the first component, unless there are less than three (e.g. "www.kde.org" -> "kde.org").
@@ -711,6 +746,19 @@ public:
      */
     KAboutData &setLicense(KAboutLicense::LicenseKey licenseKey);
 
+    /**
+     * Defines the license identifier.
+     *
+     * @param licenseKey The license identifier.
+     * @param versionRestriction Whether later versions of the license are also allowed.
+     *    e.g. licensed under "GPL 2.0 or at your option later versions" would be OrLaterVersions.
+     * @see addLicenseText, setLicenseText, setLicenseTextFile
+     *
+     * @since 5.37
+     */
+    KAboutData &setLicense(KAboutLicense::LicenseKey licenseKey,
+                           KAboutLicense::VersionRestriction versionRestriction);
+
     /**
      * Adds a license identifier.
      *
@@ -722,6 +770,22 @@ public:
      */
     KAboutData &addLicense(KAboutLicense::LicenseKey licenseKey);
 
+    /**
+     * Adds a license identifier.
+     *
+     * If there is only one unknown license set, e.g. by using the default
+     * parameter in the constructor, that one is replaced.
+     *
+     * @param licenseKey The license identifier.
+     * @param versionRestriction Whether later versions of the license are also allowed.
+     *    e.g. licensed under "GPL 2.0 or at your option later versions" would be OrLaterVersions.
+     * @see setLicenseText, addLicenseText, addLicenseTextFile
+     *
+     * @since 5.37
+     */
+    KAboutData &addLicense(KAboutLicense::LicenseKey licenseKey,
+                           KAboutLicense::VersionRestriction versionRestriction);
+
     /**
      * Defines the copyright statement to show when displaying the license.
      *
