@@ -60,7 +60,7 @@ QString KFormatPrivate::formatByteSize(double size, int precision,
     // If a specific unit conversion is given, use it directly.  Otherwise
     // search until the result is in [0, multiplier] (or out of our range).
     if (units == KFormat::DefaultBinaryUnits) {
-        while (qAbs(size) >= multiplier && unit < (int) KFormat::UnitYottaByte) {
+        while (qAbs(size) >= multiplier && unit < int(KFormat::UnitYottaByte)) {
             size /= multiplier;
             ++unit;
         }
@@ -188,13 +188,19 @@ enum TimeConstants {
 QString KFormatPrivate::formatDuration(quint64 msecs, KFormat::DurationFormatOptions options) const
 {
     quint64 ms = msecs;
+    if (options & KFormat::HideSeconds) {
+        //round to nearest minute
+        ms = qRound(ms / (qreal)MSecsInMinute) * MSecsInMinute ;
+    } else if (!(options & KFormat::ShowMilliseconds)) {
+        //round to nearest second
+        ms = qRound(ms / (qreal)MSecsInSecond) * MSecsInSecond ;
+    }
+
     int hours = ms / MSecsInHour;
     ms = ms % MSecsInHour;
     int minutes = ms / MSecsInMinute;
-    int roundMinutes = qRound(ms / 60000.0);
     ms = ms % MSecsInMinute;
     int seconds = ms / MSecsInSecond;
-    int roundSeconds = qRound(ms / 1000.0);
     ms = ms % MSecsInSecond;
 
     if ((options & KFormat::InitialDuration) == KFormat::InitialDuration) {
@@ -208,11 +214,11 @@ QString KFormatPrivate::formatDuration(quint64 msecs, KFormat::DurationFormatOpt
         } else if ((options & KFormat::FoldHours) == KFormat::FoldHours) {
             //: @item:intext Duration format minutes and seconds
             return tr("%1m%2s").arg(hours * 60 + minutes, 1, 10, QLatin1Char('0'))
-                   .arg(roundSeconds, 2, 10, QLatin1Char('0'));
+                   .arg(seconds, 2, 10, QLatin1Char('0'));
         } else if ((options & KFormat::HideSeconds) == KFormat::HideSeconds) {
             //: @item:intext Duration format hours and minutes
             return tr("%1h%2m").arg(hours, 1, 10, QLatin1Char('0'))
-                   .arg(roundMinutes, 2, 10, QLatin1Char('0'));
+                   .arg(minutes, 2, 10, QLatin1Char('0'));
         } else if ((options & KFormat::ShowMilliseconds) == KFormat::ShowMilliseconds) {
             //: @item:intext Duration format hours, minutes, seconds, milliseconds
             return tr("%1h%2m%3.%4s").arg(hours, 1, 10, QLatin1Char('0'))
@@ -223,7 +229,7 @@ QString KFormatPrivate::formatDuration(quint64 msecs, KFormat::DurationFormatOpt
             //: @item:intext Duration format hours, minutes, seconds
             return tr("%1h%2m%3s").arg(hours, 1, 10, QLatin1Char('0'))
                    .arg(minutes, 2, 10, QLatin1Char('0'))
-                   .arg(roundSeconds, 2, 10, QLatin1Char('0'));
+                   .arg(seconds, 2, 10, QLatin1Char('0'));
         }
 
     } else {
@@ -237,11 +243,11 @@ QString KFormatPrivate::formatDuration(quint64 msecs, KFormat::DurationFormatOpt
         } else if ((options & KFormat::FoldHours) == KFormat::FoldHours) {
             //: @item:intext Duration format minutes and seconds
             return tr("%1:%2").arg(hours * 60 + minutes, 1, 10, QLatin1Char('0'))
-                   .arg(roundSeconds, 2, 10, QLatin1Char('0'));
+                   .arg(seconds, 2, 10, QLatin1Char('0'));
         } else if ((options & KFormat::HideSeconds) == KFormat::HideSeconds) {
             //: @item:intext Duration format hours and minutes
             return tr("%1:%2").arg(hours, 1, 10, QLatin1Char('0'))
-                   .arg(roundMinutes, 2, 10, QLatin1Char('0'));
+                   .arg(minutes, 2, 10, QLatin1Char('0'));
         } else if ((options & KFormat::ShowMilliseconds) == KFormat::ShowMilliseconds) {
             //: @item:intext Duration format hours, minutes, seconds, milliseconds
             return tr("%1:%2:%3.%4").arg(hours, 1, 10, QLatin1Char('0'))
@@ -252,13 +258,12 @@ QString KFormatPrivate::formatDuration(quint64 msecs, KFormat::DurationFormatOpt
             //: @item:intext Duration format hours, minutes, seconds
             return tr("%1:%2:%3").arg(hours, 1, 10, QLatin1Char('0'))
                    .arg(minutes, 2, 10, QLatin1Char('0'))
-                   .arg(roundSeconds, 2, 10, QLatin1Char('0'));
+                   .arg(seconds, 2, 10, QLatin1Char('0'));
         }
 
     }
 
-    // Should never reach here
-    Q_ASSERT(false);
+    Q_UNREACHABLE();
     return QString();
 }
 
@@ -280,7 +285,7 @@ QString KFormatPrivate::formatDecimalDuration(quint64 msecs, int decimalPlaces)
     //: @item:intext %1 is a whole number
     //~ singular %n millisecond
     //~ plural %n milliseconds
-    return tr("%n millisecond(s)", 0, msecs);
+    return tr("%n millisecond(s)", nullptr, msecs);
 }
 
 enum DurationUnits {
@@ -298,22 +303,22 @@ static QString formatSingleDuration(DurationUnits units, int n)
         //: @item:intext %n is a whole number
         //~ singular %n day
         //~ plural %n days
-        return KFormatPrivate::tr("%n day(s)", 0, n);
+        return KFormatPrivate::tr("%n day(s)", nullptr, n);
     case Hours:
         //: @item:intext %n is a whole number
         //~ singular %n hour
         //~ plural %n hours
-        return KFormatPrivate::tr("%n hour(s)", 0, n);
+        return KFormatPrivate::tr("%n hour(s)", nullptr, n);
     case Minutes:
         //: @item:intext %n is a whole number
         //~ singular %n minute
         //~ plural %n minutes
-        return KFormatPrivate::tr("%n minute(s)", 0, n);
+        return KFormatPrivate::tr("%n minute(s)", nullptr, n);
     case Seconds:
         //: @item:intext %n is a whole number
         //~ singular %n second
         //~ plural %n seconds
-        return KFormatPrivate::tr("%n second(s)", 0, n);
+        return KFormatPrivate::tr("%n second(s)", nullptr, n);
     }
     Q_ASSERT(false);
     return QString();
@@ -363,7 +368,11 @@ QString KFormatPrivate::formatSpelloutDuration(quint64 msecs) const
 
 QString KFormatPrivate::formatRelativeDate(const QDate &date, QLocale::FormatType format) const
 {
-    int daysTo = QDate::currentDate().daysTo(date);
+    if (!date.isValid()) {
+        return tr("Invalid date", "used when a relative date string can't be generated because the date is invalid");
+    }
+
+    const int daysTo = QDate::currentDate().daysTo(date);
     if (daysTo > 7 || daysTo < -7) {
         return m_locale.toString(date, format);
     }
@@ -377,19 +386,42 @@ QString KFormatPrivate::formatRelativeDate(const QDate &date, QLocale::FormatTyp
         return tr("Yesterday");
     }
 
-    if (daysTo < -1)
-        /*: a day of the week, eg "Monday" (but translated). Refers to the most recent such day that
-            has already happened. */
-    {
-        return tr("Last %1").arg(m_locale.dayName(date.dayOfWeek(), format));
-    } else if (daysTo > 1)
-        /*: a day of the week, eg "Monday" (but translated). Refers to the soonest such day that
-            has not already happened. */
-    {
-        return tr("Next %1").arg(m_locale.dayName(date.dayOfWeek(), format));
+    if (daysTo < -1) {
+        switch (date.dayOfWeek()) {
+        case 1:
+            return tr("Last Monday",    "most recent such day before today");
+        case 2:
+            return tr("Last Tuesday",   "most recent such day before today");
+        case 3:
+            return tr("Last Wednesday", "most recent such day before today");
+        case 4:
+            return tr("Last Thursday",  "most recent such day before today");
+        case 5:
+            return tr("Last Friday",    "most recent such day before today");
+        case 6:
+            return tr("Last Saturday",  "most recent such day before today");
+        case 7:
+            return tr("Last Sunday",    "most recent such day before today");
+        }
+    } else if (daysTo > 1) {
+        switch (date.dayOfWeek()) {
+        case 1:
+            return tr("Next Monday",    "the next such day after today");
+        case 2:
+            return tr("Next Tuesday",   "the next such day after today");
+        case 3:
+            return tr("Next Wednesday", "the next such day after today");
+        case 4:
+            return tr("Next Thursday",  "the next such day after today");
+        case 5:
+            return tr("Next Friday",    "the next such day after today");
+        case 6:
+            return tr("Next Saturday",  "the next such day after today");
+        case 7:
+            return tr("Next Sunday",    "the next such day after today");
+        }
     }
-
-    return m_locale.toString(date, format);
+    Q_UNREACHABLE();
 }
 
 QString KFormatPrivate::formatRelativeDateTime(const QDateTime &dateTime, QLocale::FormatType format) const
